//
// Article.H -- Manage newsgroup articles
// 1.00 erco@3dsite.com 12/16/02
//
// Copyright 2003-2004 Michael Sweet
// Copyright 2002 Greg Ercolano
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public Licensse as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//

#ifndef ARTICLE_H
#define ARTICLE_H

#include "everything.H"

class Article
{
    char group[GROUP_MAX];		// group name
    char filename[LINE_LEN];		// full path to the article
    unsigned long number;		// article number
    int valid;				// article is valid (0=invalid)

    // commonly accessed header info
    char from[FIELD_MAX];		// From: field
    char date[FIELD_MAX];		// Date: field
    char messageid[FIELD_MAX];		// Message-ID: field
    char subject[FIELD_MAX];		// Subject: field
    char references[FIELD_MAX];		// References: field
    char xref[FIELD_MAX];		// Xref: field
    int lines;				// Lines: field

    string errmsg;			// error message

    void _Copy(const Article& o)
    {
        strcpy(group, o.group);
        strcpy(filename, o.filename);
        number = o.number;
	valid = o.valid;
	strcpy(from, o.from);
	strcpy(date, o.date);
	strcpy(messageid, o.messageid);
	strcpy(subject, o.subject);
	strcpy(references, o.references);
	strcpy(xref, o.xref);
	lines = o.lines;
	errmsg = o.errmsg;
    }

public:

    Article() 
    {
        group[0] = filename[0] = 0;
	from[0] = messageid[0] = 0;
	date[0] = references[0] = 0;
	subject[0] = xref[0] = 0; 
	lines = 0;
	number = 0; 
	valid = 0;
    }

    ~Article() { } 

    Article(const Article& o)
	{ _Copy(o); }

    Article& operator=(const Article& o)
	{ _Copy(o); return(*this); }

    int            IsValid()    { return(valid); }
    const char    *Group()      { return(group); }
    const char    *Filename()   { return(filename); }
    const char    *From()       { return(from); }
    const char    *Date()       { return(date); }
    const char    *MessageID()  { return(messageid); }
    const char    *Subject()    { return(subject); }
    const char    *Xref()       { return(xref); }
    const char    *References() { return(references); }
    int            Lines()      { return(lines); }
    unsigned long  Number()     { return(number); }
    const char    *Errmsg()     { return(errmsg.c_str()); }

    int Load(const char *group, unsigned long num);	// load info for group/article
    int Load(unsigned long num);			// load info for article
    int SendArticle(int fd, int head=1, int body=1);	// send article to remote via fd
    int SendHead(int fd);				// send article head only
    int SendBody(int fd);				// send article body only
    void Overview(string &reply, const char *overview[] );
};

#endif /*!ARTICLE_H*/
